[![DL stat](https://img.shields.io/pypi/v/mypdns.png)](https://pypi.org/project/mypdns)
[![Downloads](https://static.pepy.tech/personalized-badge/mypdns?period=total&units=none&left_color=black&right_color=brightgreen&left_text=Downloads)](https://pepy.tech/project/mypdns)
[![Downloads](https://static.pepy.tech/personalized-badge/mypdns?period=month&units=none&left_color=black&right_color=brightgreen&left_text=Downloads)](https://pepy.tech/project/mypdns)
[![Downloads](https://static.pepy.tech/personalized-badge/mypdns?period=week&units=none&left_color=black&right_color=brightgreen&left_text=Downloads)](https://pepy.tech/project/mypdns)


Namespace Reservation for the [mypdns.org](https://mypdns.org/python/mypdns) project
